import request from '@/utils/request'

/**
 * 新增客户
 * @param customerName 客户名
 * @param customerEmail 客户邮箱
 * @param customerContact 客户联系人
 * @param customerPhone 客户电话
 * @param customerAddress 客户地址
 * @param status 状态
 * @param startTime 开始时间
 * @param endTim 结束时间
 */
export function addCustomer({ customerName, customerEmail, customerContact, customerPhone, customerAddress, status, customerOperator, customerArea, contractTime, type }) {
  return request({
    url: '/system/customer/',
    method: 'POST',
    data: { customerName, customerEmail, customerContact, customerPhone, customerAddress, customerOperator, customerArea, status, contractTime, type }
  })
}

/**
 * 修改客户
 * @param customerId 客户ID
 * @param customerName 客户名称
 * @param customerEmail 客户邮箱
 * @param customerContact 客户联系人
 * @param customerPhone 客户联系电话
 * @param customerAddress 客户地址
 * @param status 状态
 * @param contractTime 合同时间
 */
export function editCustomer({ customerId, customerName, customerEmail, customerContact, customerPhone, customerAddress, customerOperator, customerArea, status, contractTime, type }) {
  return request({
    url: '/system/customer/' + customerId,
    method: 'PUT',
    data: {
      customerId,
      customerName,
      customerEmail,
      customerContact,
      customerPhone,
      customerAddress,
      status,
      contractTime,
      customerOperator, 
      customerArea,
      type
    }
  })
}

/**
 * 获取客户列表
 * @param current 当前页
 * @param size 每页记录数
 * @param customerName 客户名称
 * @param status 客户状态
 * @param startTime
 * @param endTime
 * @returns {Promise<void> | * | AxiosPromise<any> | ClientHttp2Stream | http.ClientRequest}
 */
export function listCustomer({ current, size, customerName, customerArea, customerOperator, status, startTime, endTime, type }) {
  return request({
    url: '/system/customer/list',
    method: 'POST',
    data: { current, size, customerName, status, startTime, endTime, customerArea, customerOperator, type }
  })
}

/**
 * 获取客户
 * @param customerId 客户ID
 */
export function getCustomer(customerId) {
  return request({
    url: '/system/customer/' + customerId,
    method: 'GET'
  })
}

/**
 * 删除客户
 * @param customerId 客户ID
 */
export function deleteCustomer(customerId) {
  return request({
    url: '/system/customer/' + customerId,
    method: 'DELETE'
  })
}

export function editStatus(customerId, status) {
  return request({
    url: '/system/customer/' + customerId + '/' + status,
    method: 'PUT'
  })
}

export function resetPassword(customerId) {
  return request({
    url: `/system/customer/${customerId}/password/reset`,
    method: 'POST'
  })
}

/**
 * 客户产品List - 导出数据接口
 * @param customerName 客户名称
 * @param status 客户状态
 * @param startTime
 * @param endTime
 * **/
export function productExport(data) {
  return request({
    url: '/system/customer/export',
    method: 'POST',
    data,
    responseType: 'arraybuffer'
  })
}
